package IIP::Database;

use strict;
use warnings FATAL => 'all';

use IIP::Package;
use KreaTV;

sub new {
    my ($class, $toolchain, $hw) = @_;
    my $self = bless({}, $class);

    $self->{toolchain} = $toolchain;
    $self->{hw} = $hw;

    $self->{cache} = {};
    $self->{iips} = [];

    return $self;
}

sub _get_iip_path {
    my ($self, $name, $toolchain, $hw) = @_;
    my $re = "^(.*/)?" . quotemeta($name) . "_(INTERNAL-USE-ONLY_)?[^_]+";

    if (defined $toolchain) {
        if ($toolchain eq "*") {
            $re .= "_[^_]+";
        }
        else {
            $re .= "_" . quotemeta($toolchain);
        }
    }
    if (defined $hw) {
        if ($hw eq "*") {
            $re .= "_[^_]+";
        }
        else {
            $re .= "_" . quotemeta($hw);
        }
    }

    $re .= "\\.iip\$";

    my @iips = grep(/$re/, @{$self->{iips}});

    if (@iips) {
        return \@iips;
    }
    elsif (!defined($toolchain) and !defined($hw)) {
        return [];
    }
    else {
        if (defined $hw) {
            $hw = undef;
        }
        else {
            $toolchain = undef;
        }
        return $self->_get_iip_path($name, $toolchain, $hw);
    }
}

sub get_iip_path {
    my ($self, $name, $version) = @_;

    # If name starts with / it is assumed to be the full path to the IIP.
    if ($name =~ /^\//) {
        return "" if (! -e $name || -d $name);
        return $name;
    }

    my $iips = $self->_get_iip_path($name, $self->{toolchain}, $self->{hw});
    my $iip = (grep(/^(.*\/)?${name}_(INTERNAL-USE-ONLY_)?$version/, @$iips))[0];
    if (!$iip) {
        $iip = @$iips[0];
    }
    return $iip;
}

sub get_iip {
    my $self = shift;
    my $path = $self->get_iip_path(@_);

    return undef unless $path;

    if (!exists($self->{cache}{$path})) {
        $self->{cache}{$path} = IIP::Package->new($path);
    }

    return $self->{cache}{$path};
}

sub add_iips_from_path {
    my ($self, $path) = @_;

    my $re = '^\(.*/\)?[^_]+_\(INTERNAL-USE-ONLY_\)?[^_]+\(_' . $self->{toolchain} . '[^/]*\)?\.iip$';
    my @iips = KreaTV::backticks("find '$path' -regex '$re'");
    chomp $_ foreach @iips;
    push(@{$self->{iips}}, @iips);
}

1;
