package IIP::Package;

use strict;
use warnings FATAL => 'all';

use KreaTV;
use IIP::Info;

use Cwd;
use File::Path;
use File::Temp;

sub new {
    my $class = shift;
    my $self = bless({}, $class);

    $self->{iip} = shift;
    if (! -e $self->{iip} || -d $self->{iip}) {
        return undef;
    }

    $self->{version} = undef;
    $self->{info} = undef;
    $self->{install_types} = undef;
    $self->{uninstall_types} = undef;
    $self->{tempdir} = File::Temp::tempdir("iip-XXXXXXXX",
                                           CLEANUP => 0,
                                           TMPDIR => 1);
    KreaTV::system("tar zxpf '$self->{iip}' -C '$self->{tempdir}'");

    return $self;
}

sub DESTROY {
    my $self = shift;
    File::Path::rmtree($self->{tempdir});
}

sub _get_file_content {
    my ($self, $file) = @_;
    return KreaTV::read_file_content("$self->{tempdir}/$file");
}

sub _get_directory_content {
    my ($self, $directory) = @_;
    my @files;
    my @result;

    @files = glob("$self->{tempdir}/$directory/*");
    s!.*/!! foreach @files;
    return \@files;
}

sub version {
    my $self = shift;
    unless (defined($self->{version})) {
        $self->{version} = $self->_get_file_content("iip_version");
        chomp $self->{version};
    }
    return $self->{version};
}

sub install_types {
    my $self = shift;
    unless (defined($self->{install_types})) {
        $self->{install_types} = $self->_get_directory_content("install");
    }
    return $self->{install_types};
}

sub uninstall_types {
    my $self = shift;
    unless (defined($self->{uninstall_types})) {
        $self->{uninstall_types} = $self->_get_directory_content("uninstall");
    }
    return $self->{uninstall_types};
}

sub info {
    my $self = shift;
    unless (defined($self->{info})) {
        $self->{info} = IIP::Info->new();
        $self->{info}->load_from_string($self->_get_file_content("info.xml"));
    }
    return $self->{info};
}

sub install {
    my ($self, $rootdisk) = @_;

    my $name = $self->info()->name();
    print "\nInstalling IIP $name\nUsing file $self->{iip}\n";

    unless (-f "$self->{tempdir}/install/buildtime") {
        KreaTV::error("no 'buildtime' install script in IIP '$name'");
    }

    my $current = cwd();
    my $params = $self->info()->params() || "";

    chdir("$self->{tempdir}/data");
    my $retval = system(("$self->{tempdir}/install/buildtime",
                         $rootdisk, $params));
    chdir($current);

    if ($retval) {
        print "\n";
        KreaTV::error("buildtime install script failed for IIP '$name' " .
                      "with parameters '$params'");
    }
}

1;
