use strict;
use warnings FATAL => 'all';

package KreaTV;

sub error {
    my $message = shift;
    my $func = shift;

    print STDERR "Error: $message\n";
    if (defined($func)) {
        &$func();
    }
    exit 1;
}

sub command_error {
    my $command = shift;
    my $context = shift;

    error("$command failed at @{$context}[1] line @{$context}[2]");
}

sub system {
    my $command = shift;

    if (system($command)) {
        my @context = caller;
        command_error($command, \@context);
    }
}

sub backticks {
    my $command = shift;

    if (wantarray) {
        my @output = `$command`;
        if ($?) {
            my @context = caller;
            command_error($command, \@context);
        }
        return @output;
    }
    else {
        my $output = `$command`;
        if ($?) {
            my @context = caller;
            command_error($command, \@context);
        }
        return $output;
    }
}

sub replace_in_file {
    my $file = shift;
    my $regexp = shift;
    my $replace = shift;

    my $data = backticks("cat $file");

    if (ref($replace) eq "CODE") {
        $data =~ s!$regexp!$replace->()!ge;
    }
    else {
        $data =~ s!$regexp!$replace!g;
    }

    open(FILE, "> $file");
    print FILE $data;
    close FILE;
}

sub read_file_content {
    my $path = shift;

    my @context = caller;
    open FILE, "<$path" or command_error("read_file_content", \@context);
    return do { local $/; <FILE> };
}

sub write_file_content {
    my ($path, $content) = @_;

    my @context = caller;
    open FILE, ">$path" or command_error("write_file_content", \@context);
    print FILE $content or command_error("write_file_content", \@context);
    close FILE;
}

1;
