#!/bin/bash

# Copyright (c) 2008 Motorola, Inc. All Rights Reserved.
# Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

set -e
set -u

architecture="$1"
rootdisk="$2"
image="$3"
squashfs="$4"
dev_file="$5"

PATH=$(dirname $0)/../host/bin:$(dirname $0)/../3pp/bin:$(dirname $0):$PATH

list=$(mktemp initramfs_list.XXXXXX)
trap "rm '$list'" EXIT

if [ "$squashfs" != "/dev/null" ]; then
    (cd $rootdisk; mksquashfs * $squashfs -le -all-root -no-progress -no-exports -processors 1 -no-fragments -e dev )
    unsquashfs -n -d /tmp/$$_temp-sqfs-root -f $squashfs 2>&1 | awk '/zlib::uncompress failed/ { exit 1; }' ;
    rm -rf /tmp/$$_temp-sqfs-root

    echo "dir /dev 0755 0 0" >> $list
    echo "nod /dev/mem 0640 0 0 c 1 1" >> $list
    echo "nod /dev/console 0664 0 0 c 5 1" >> $list
    echo "nod /dev/loop0 0660 0 0 b 7 0" >> $list
    echo "nod /dev/rootdisk0 0660 0 0 b 1 0" >> $list
    echo "nod /dev/mtdblock2 0660 0 0 b 31 2" >> $list
    echo "file /init $rootdisk/init 0755 0 0" >> $list
else
    sh gen_initramfs_list_${architecture}.sh $rootdisk > $list
    echo "slink /init /sbin/init 755 0 0" >> $list
    cat ${dev_file} >> $list
fi

# Make sure everything is owned by root
perl -ani -e 'if (/^[dfnps]/) {
  $uid = (/^file/ || /^slink/) ? 4 : 3;
  $F[$uid] = $F[$uid+1] = 0;
}
print join(" ", @F), "\n";' $list

gen_init_cpio_$architecture $list | gzip -9 > $image
