var mediaPlayer = null;
var channels = [
  "224.5.5.2:11111",
  "224.5.5.1:11111",
  "224.5.80.1:10000"
  ];

var currChan = 0;  // counts from zero (its array position)
var currAudioChan = 1; // this counts from 1
var dataAvailable = false;

var numAudioTracks = 0;

function onLoad() {
  if (!toi) {
    alert("TOI/JS 2 is not available, please check your whitelisturls.xml");
    alert(" and that your boot image supports TOI/JS 2.");
    return;
  }
  createPlayer();
  document.addEventListener("keydown", onKeyDown, false);
}


function createPlayer() {
  try {
    mediaPlayer = toi.mediaService.createPlayerInstance();
    mediaPlayer.addEventListener(mediaPlayer.ON_DATA_AVAILABLE,
                    onDataAvailable);
  }
  catch (e) {
    alert("Failed creating player!");
    alert(e);
  }

  var video = document.getElementById("videoplane");
  video.setAttribute("ekioh:colourKey","#ff0000"); // 00?
  play(channels[currChan]);
}




function play(uri) {
  try {
    if (mediaPlayer == null) {
      alert("play has no mediaplayer!");
    }

    if (mediaPlayer.getState() > mediaPlayer.STATE_IDLE) {
      alert("PLAY: mediaplayer doing stuff, stopping previous stream");
      mediaPlayer.close();
    }

    alert("PLAY: " + uri);

    document.getElementById("videouri"). textContent = uri;
    mediaPlayer.open(uri);
    mediaPlayer.play(mediaPlayer.PACE_PLAY);
  }
  catch (e) {
    alert(e);
  }

}


function onDataAvailable(event) {
  dataAvailable = event.status;

  if (event.status == true ) {
    updateAudioStreamInfo();
  }
}


function onKeyDown(event) {
  var key = event.keyIdentifier;

  switch (key) {
    case "Red":
      updateAudioStreamInfo();
      break;
    case "Blue":
        alert("Removing listeners from playing media player");
        mediaPlayer.removeEventListener(mediaPlayer.ON_DATA_AVAILABLE,
                                        onDataAvailable);
        break;
    case "Right":
      incAudio();
      break;
    case "Left":
      decAudio();
      break;
    case "Up":
      incChan();
      play(channels[currChan]);
      break;
    case "Down":
      decChan();
      play(channels[currChan]);
      break;
  }
}


function incChan() {
  currAudioChan = 1;
  currChan = currChan + 1;
  if (currChan == channels.length ) {
    currChan = 0;
  }
}

function decChan() {
  currAudioChan = 1;
  currChan = currChan - 1;
  if (currChan < 0 ) {
    currChan = channels.length - 1;
  }
}

function incAudio() {
  if (currAudioChan != numAudioTracks ) {
    currAudioChan++;
  }
  updateAudioStreamInfo();
}

function decAudio() {
  currAudioChan--;
  if (currAudioChan == 0) {
    currAudioChan = 1;
  }
  updateAudioStreamInfo();
}


function updateAudioStreamInfo() {
  if (!dataAvailable) {
    alert("Data not available");
    // it could be a good idea to remove any info already on screen now..
    return;
  }

  // get a list of components in the stream (audio tracks, video, subs..)
  var streamInfo = mediaPlayer.getStreamInfo();
  var clist = streamInfo.availableComponents;

  // count the number of audio tracks
  var x;
  numAudioTracks = 0;
  for (x=0; x<clist.length; x++) {
    if (clist[x].type == mediaPlayer.COMPONENT_AUDIO) {
      numAudioTracks++;
    }
  }

  var element = document.getElementById("currAudio");
  element.textContent = currAudioChan + " / " + numAudioTracks;

  var audioTrack = 0;
  var audioStreamInfo = 0;

  // now find the current audio track, and get info
  for (x=0; x<clist.length; x++) {
    if (clist[x].type == mediaPlayer.COMPONENT_AUDIO) {
      audioTrack++;
      if (audioTrack == currAudioChan) {
        try {
          audioStreamInfo = mediaPlayer.getAudioStreamInfo(clist[x]);
        }
        catch (e) {
        }
        break;
      }
    }
  }

  mediaPlayer.activateComponent(clist[x]);

  // Now the values are read from the audioStreamInfo structure
  // and placed into the document

  element = document.getElementById("encoding");
  element.textContent = audioStreamInfo.encoding;

  element = document.getElementById("samplerate");
  element.textContent = audioStreamInfo.sampleRate;

  element = document.getElementById("format");
  switch (audioStreamInfo.channelFormat) {
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_STEREO:
      element.textContent = "AUDIO_CHANNEL_FORMAT_STEREO";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_SINGLE_MONO:
      element.textContent = "AUDIO_CHANNEL_FORMAT_SINGLE_MONO";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_DUAL_MONO:
      element.textContent = "AUDIO_CHANNEL_FORMAT_DUAL_MONO";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_3_FRONT_1_BACK:
      element.textContent = "AUDIO_CHANNEL_FORMAT_3_FRONT_1_BACK";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_3_FRONT_2_BACK:
      element.textContent = "AUDIO_CHANNEL_FORMAT_3_FRONT_2_BACK";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_3_FRONT_2_BACK_LFE:
      element.textContent = "AUDIO_CHANNEL_FORMAT_3_FRONT_2_BACK_LFE";
      break;
    case mediaPlayer.AUDIO_CHANNEL_FORMAT_3_FRONT_2_SIDE_2_BACK_LFE:
      element.textContent = "AUDIO_CHANNEL_FORMAT_3_FRONT_2_SIDE_2_BACK_LFE";
      break;
    default:
      element.textContent = "AUDIO_CHANNEL_FORMAT_UNKNOWN";
  }

  element = document.getElementById("mode");
  switch (audioStreamInfo.channelMode) {
    case mediaPlayer.AUDIO_CHANNEL_MODE_NORMAL:
      element.textContent = "AUDIO_CHANNEL_MODE_NORMAL";
      break;
    case mediaPlayer.AUDIO_CHANNEL_MODE_DUAL_MONO_LEFT_ONLY:
      element.textContent = "AUDIO_CHANNEL_MODE_DUAL_MONO_LEFT_ONLY";
      break;
    case mediaPlayer.AUDIO_CHANNEL_MODE_DUAL_MONO_RIGHT_ONLY:
      element.textContent = "AUDIO_CHANNEL_MODE_DUAL_MONO_RIGHT_ONLY";
      break;
    case mediaPlayer.AUDIO_CHANNEL_MODE_DUAL_MONO_STEREO:
      element.textContent = " AUDIO_CHANNEL_MODE_DUAL_MONO_STEREO";
      break;
    case mediaPlayer.AUDIO_CHANNEL_MODE_DUAL_MONO_MIXED:
      element.textContent = "AUDIO_CHANNEL_MODE_DUAL_MONO_MIXED";
      break;
    default:
      element.textContent = "Unknown";
  }

  element = document.getElementById("language");
  element.textContent = audioStreamInfo.language;

  element = document.getElementById("subs");
  element.textContent = audioStreamInfo.sublanguage;

  element = document.getElementById("audience");
  switch (audioStreamInfo.audienceType) {
    case mediaPlayer.AUDIO_AUDIENCE_TYPE_NORMAL:
      element.textContent = "AUDIO_AUDIENCE_TYPE_NORMAL";
      break;
    case mediaPlayer.AUDIO_AUDIENCE_TYPE_VISUALLY_IMPAIRED:
      element.textContent = "AUDIO_AUDIENCE_TYPE_VISUALLY_IMPAIRED";
      break;
    default:
      element.textContent = "AUDIO_AUDIENCE_TYPE_UNKNOWN";
  }

  element = document.getElementById("component");
  element.textContent = audioStreamInfo.componentTag;
}


function onUnload() {
  try {
    document.removeEventListener("keydown", onKeyDown, false);

    if ( mediaPlayer.getState != mediaPlayer.STATE_IDLE ) {
        mediaPlayer.close();
    }
    mediaPlayer.removeEventListener(mediaPlayer.ON_DATA_AVAILABLE,
                    onDataAvailable);

    mediaPlayer.releaseInstance();
  }
  catch (e) {
    alert("oh noes! " + e);
  }
}

