var channel = "igmp://224.5.80.1:10000";

var currentTime = 0;
var e_currentTime = 0; // DOM element used to display time

// hours and minutes entered into the time selector
var setHours = 0;
var setMinutes = 0;

var selectingHours = 0; // true if focus is on the Hours

var e_hourSelect = 0; // focus rectangle
var e_minSelect = 0;

var e_status = 0; // status messages

var bookingId = 0;

var mediaRecorder = 0;
var mediaPlayer = 0;


function onLoad() {
  try {
    document.addEventListener("keydown", onKeyDown, false);
    var ss = toi.schedulerService;
    ss.addEventListener(ss.ON_SCHEDULED_START, onScheduledStart);
    ss.addEventListener(ss.ON_SCHEDULED_STOP, onScheduledStop);

    ss.setCategorySubscription(onScheduledStart, "*");
    ss.setCategorySubscription(onScheduledStop, "*");

    mediaPlayer = toi.mediaService.createPlayerInstance();
    mediaPlayer.addEventListener(mediaPlayer.ON_STATE_CHANGED,
                      onStateChanged);
  }
  catch (e) {
    alert(e);
  }

  mediaPlayer.open(channel);
  mediaPlayer.play(mediaPlayer.PACE_PLAY);

  e_currentTime   = document.getElementById("currentTime");
  e_hourSelect  = document.getElementById("hourSelect");
  e_minSelect   = document.getElementById("minSelect");
  e_status    = document.getElementById("status");

  updateCurrentTime();

  // get a good default for the time selection spinner
  setHours  = currentTime.getHours();
  setMinutes  = currentTime.getMinutes() + 2;
  if (setMinutes > 59) setMinutes = setMinutes - 60;
  if (setMinutes.length == 1) setMinutes = "0" + setMinutes;

  updateTimeSpinner();

  // we begin with the selection focus on the Minutes
  e_hourSelect.setAttribute("display", "none");
  e_minSelect.setAttribute("display", "relative");
  selectingHours = false;

  setStatusMessage("Idle", "#000000");
}


function onScheduledStart(event) {
  // event is of type ToiSchedulerServiceBooking, see docs
  try {
    mediaRecorder = toi.mediaService.createRecorderInstance();
    var assetId = toi.assetManagerService.createAsset(toi.assetManagerService.ASSET_PVR);

    mediaRecorder.open(channel, assetId);

    var propList = new Array(toi.assetManagerService.PROPERTY_SYSTEM_PLAYBACKURI);
    var properties = toi.assetManagerService.getProperties(assetId, propList);
    var assetURI = properties[0].value;

    // save the assetId in the booking
    toi.schedulerService.setParameter(event.booking.id, "assetURI", assetURI);

    mediaRecorder.record();
    setStatusMessage("Recording to " + assetURI, "#ff0000");
  }
  catch (e) {
    alert(e);
  }
}


function onScheduledStop(event) {
  try {
    mediaRecorder.close();
    mediaPlayer.close();

    // determine which booking (in case of multiple bookings) just ended...
    var assetURI = toi.schedulerService.getParameter(event.booking.id,
                                                     "assetURI");
    alert("finished recording " + assetURI);

    mediaPlayer.open(assetURI);
    mediaPlayer.play(mediaPlayer.PACE_PLAY);
    setStatusMessage("Playing", "#00ff00");
  }
  catch (e) {
    alert(e);
  }
}



function onStateChanged(event) {
  if (event.reason == "PositionEnd" &&
      mediaPlayer.getState() == mediaPlayer.STATE_PAUSED) {
    // finished playing back the asset. start with live tv again
    mediaPlayer.close();
    mediaPlayer.open(channel);
    mediaPlayer.play(mediaPlayer.PACE_PLAY);

    setStatusMessage("Idle", "#000000");
  }
}


function setStatusMessage(msg, color) {
  e_status.textContent = msg;
  e_status.setAttribute("fill", color);
}


// this function gets the current time, formats it for display, and displays it
// in the portal (hours:mins:secs)
function updateCurrentTime() {
  currentTime = new Date();
  var currH = currentTime.getHours().toString();
  var currM = currentTime.getMinutes().toString();
  var currS = currentTime.getSeconds().toString();

  var timeString = 0;

  if (currH.length == 1) {
    timeString = "0" + currH;
  }
  else {
    timeString = currH;
  }

  timeString = timeString + ":";

  if (currM.length == 1) {
    timeString = timeString + "0" + currM;
  }
  else {
    timeString = timeString + currM;
  }

  timeString = timeString + ":";

  if (currS.length == 1) {
    timeString = timeString + "0" + currS;
  }
  else {
    timeString = timeString + currS;
  }

  e_currentTime.textContent = timeString;

  // call this function again 1000ms from now
  setTimeout("updateCurrentTime()", 1000);
}


function updateTimeSpinner() {
  var e = document.getElementById("setHours");
  var h = setHours.toString();
  if (h.length == 1) {
    e.textContent = "0" + setHours;
  }
  else {
    e.textContent = setHours;
  }

  e = document.getElementById("setMinutes");

  var m = setMinutes.toString();
  if (m.length == 1) {
    e.textContent = "0" + setMinutes;
  }
  else {
    e.textContent = setMinutes;
  }
}


function onKeyDown(event) {
   var key = event.keyIdentifier;
   switch (key) {
    case "Left":
      e_minSelect.setAttribute("display", "none");
      e_hourSelect.setAttribute("display", "relative");
      selectingHours = true;
      break;
    case "Right":
      e_minSelect.setAttribute("display", "relative");
      e_hourSelect.setAttribute("display", "none");
      selectingHours = false;
      break;
    case "Up":
      if (selectingHours) {
        setHours = setHours + 1;
        if (setHours == 24) {
          setHours = 0;
        }
      }
      else {
        setMinutes = setMinutes + 1;
        if (setMinutes == 60) {
          setMinutes = 0;
        }
      }
      updateTimeSpinner();
      break;
    case "Down":
      if (selectingHours) {
        setHours = setHours - 1;
        if (setHours < 0) {
          setHours = 23;
        }
      }
      else {
        setMinutes = setMinutes - 1;
        if (setMinutes < 0) {
          setMinutes = 59;
        }
      }
      updateTimeSpinner();
      break;

    case "Red":
      createBooking();
      break;
    case "Blue":
      removeBooking();
      break;
   }
}


function createBooking() {
  var startTime = new Date();
  startTime.setHours(setHours);
  startTime.setMinutes(setMinutes);
  startTime.setSeconds(0);

  try {
    bookingId = toi.schedulerService.schedule("activity_1",
                          "record_hd_from_ip",
                          startTime.getTime()/1000,
                          60);
    setStatusMessage("Waiting...", "#000000");
  }
  catch (e) {
    alert(e);
  }
}


function removeBooking() {
  try {
    toi.schedulerService.remove(bookingId);
    setStatusMessage("Idle", "#000000");
  }
  catch (e) {
    alert(e);
  }
}


function onUnload() {
  mediaPlayer.releaseInstance();
}



