var mediaPlayer = null;
var channels = [
  "igmp://224.5.5.2:11111",
  "igmp://224.5.5.1:11111",
  "igmp://224.5.80.1:10000"
  ];

// commonly accessed elements so getElementById() isn't
// getting called all the time

var e_videoplane        = 0;
var e_istimeshifting    = 0;
var e_bufferremaining   = 0;
var e_mediaplayerstate  = 0;
var e_mediaplayerreason = 0;
var e_position          = 0;
var e_pace              = 0;
var e_timeshiftstate    = 0;
var e_timeshiftreason   = 0;
var e_videouri          = 0;

// Timeshift is not started until a 5 second timer expires. This variable holds
// the timer ID so it can be cancelled should the portal user zap to another
// channel before the timer expires
var initialDelayID = -1;

var currChan = 0; // the channel being watched

function onLoad() {
  if (!toi) {
    alert("TOI/JS 2 is not available, please check your whitelisturls.xml");
    alert(" and that your boot image supports TOI/JS 2.");
    return;
  }

  e_videoplane        = document.getElementById("videoplane");
  e_istimeshifting    = document.getElementById("istimeshifting");
  e_bufferremaining   = document.getElementById("bufferremaining");
  e_mediaplayerstate  = document.getElementById("mediaplayerstate");
  e_mediaplayerreason = document.getElementById("mediaplayerreason");
  e_position          = document.getElementById("position");
  e_pace              = document.getElementById("pace");
  e_timeshiftstate    = document.getElementById("timeshiftstate");
  e_timeshiftreason   = document.getElementById("timeshiftreason");
  e_videouri          = document.getElementById("videouri");

  createPlayer();
  document.addEventListener("keydown", onKeyDown, false);
  setTimeout("updateState();", 1000);
}


function createPlayer() {
  try {
    mediaPlayer = toi.mediaService.createPlayerInstance();
    mediaPlayer.addEventListener(mediaPlayer.ON_STATE_CHANGED,
                    onStateChanged);
    mediaPlayer.addEventListener(mediaPlayer.ON_POSITION_CHANGED,
                    onPositionChanged);
    mediaPlayer.addEventListener(mediaPlayer.ON_TIMESHIFT_STATE_CHANGED,
                    onTimeshiftStateChanged);
  }
  catch (e) {
    alert("Failed creating player!");
    alert(e);
  }

  e_videoplane.setAttribute("ekioh:colourKey","#ff0000");
  play(channels[currChan]);
}


function updateState() {
  if (mediaPlayer.isTimeshiftPlayback()) {
        e_istimeshifting.textContent = "Timeshift playback";
  }
  else {
    e_istimeshifting.textContent = "Live playback";
  }

  var capacity = mediaPlayer.getTimeshiftInfo().bufferCapacity;
  var remaining = capacity - mediaPlayer.getTimeshiftInfo().bufferUsed;

  e_bufferremaining.textContent = remaining + " secs";
  e_position.textContent = mediaPlayer.getPosition() / 1000 + " secs";
  setTimeout("updateState();", 1000);
}


function onStateChanged(event) {
  alert("EVENT! " + event.reason);

  e_mediaplayerstate.textContent = event.state;

  switch (event.state) {
    case mediaPlayer.STATE_IDLE:
      e_mediaplayerstate.textContent = "STATE_IDLE";
      break;
    case mediaPlayer.STATE_CONNECTING:
      e_mediaplayerstate.textContent = "STATE_CONNECTING";
      break;
    case mediaPlayer.STATE_PAUSED:
      e_mediaplayerstate.textContent = "STATE_PAUSED";
      break;
    case mediaPlayer.STATE_PLAYING:
      e_mediaplayerstate.textContent = "STATE_PLAYING";
      break;
    case mediaPlayer.STATE_FASTFORWARDING:
      e_mediaplayerstate.textContent = "STATE_FASTFORWARDING";
      break;
    case mediaPlayer.STATE_REWINDING:
      e_mediaplayerstate.textContent = "STATE_REWINDING";
      break;
    case mediaPlayer.STATE_FAILED:
      e_mediaplayerstate.textContent = "STATE_FAILED";
      break;
  }

  if (event.reason == toi.mediaService.REASON_POSITION_END) {
      // we have reached the end of the timeshift buffer, go back to
      // live tv
      mediaPlayer.playFromPosition(mediaPlayer.POSITION_LIVE,
                                   mediaPlayer.PACE_PLAY);
  }

  e_mediaplayerreason.textContent = event.reason;
}

function onPositionChanged(event) {
    // I poll mediaPlayer.getPosition() instead of this, this event only
    // occurs every couple of seconds...
    // e_position.textContent = event.position / 1000 + " secs";

    e_pace.textContent = event.pace;
}

function onTimeshiftStateChanged(event) {
  switch (event.state) {
    case mediaPlayer.TIMESHIFT_STATE_INACTIVE:
      e_timeshiftstate.textContent = "TIMESHIFT_STATE_INACTIVE";
      break;
    case mediaPlayer.TIMESHIFT_STATE_BUFFERING:
      e_timeshiftstate.textContent = "TIMESHIFT_STATE_BUFFERING";
      break;
    case mediaPlayer.TIMESHIFT_STATE_STOPPED:
      e_timeshiftstate.textContent = "TIMESHIFT_STATE_STOPPED";
      break;
    case mediaPlayer.TIMESHIFT_STATE_BUFFERING_FAILED:
      e_timeshiftstate.textContent = "TIMESHIFT_STATE_BUFFERING_FAILED";
      break;
  }
  e_timeshiftreason.textContent = event.reason;
}


function resetValues() {
  // this resets the info in the DOM
  e_position.textContent = "-";
  e_pace.textContent = "-";
  e_mediaplayerreason.textContent = "-";
  e_mediaplayerstate.textContent = "-";
  e_timeshiftreason.textContent = "-";
  e_timeshiftstate.textContent = "-";
  e_istimeshifting.textContent = "-";
  e_videouri.textContent = "-";
}




function play(uri) {
  try {
    if (mediaPlayer == null) {
      alert("play has no mediaplayer!");
    }

    if (initialDelayID != -1) {
      clearTimeout(initialDelayID);
      initialDelayID = -1;
    }

    if (mediaPlayer.getState() != mediaPlayer.STATE_IDLE) {
      mediaPlayer.close();
    }

    resetValues();

    e_videouri.textContent = uri;
    mediaPlayer.open(uri);
    mediaPlayer.play(mediaPlayer.PACE_PLAY);

    // begin timeshift recording after 5 seconds (to avoid unnecessary
    // activity when the user is quickly zapping through channels
    initialDelayID = setTimeout("startTimeshiftBuffering();", 5000);
  }
  catch (e) {
    alert(e);
    // show timeshift errors
    alert("error: " + mediaPlayer.getTimeshiftError().source);
    alert("error: " + mediaPlayer.getTimeshiftError().details);
  }
}

function startTimeshiftBuffering() {
    // check that media player is working
    if (mediaPlayer.getState() != mediaPlayer.STATE_PLAYING ) {
      alert("Media Player must be playing when starting timeshift buffering!");
      return;
    }

    mediaPlayer.startTimeshiftBuffering(600);
}


function onKeyDown(event) {
  var key = event.keyIdentifier;
  alert("Key = " + key);

  switch (key) {
    case "Red":  // stop timeshifting
      try {
        if (mediaPlayer.getTimeshiftInfo().state !=
              mediaPlayer.TIMESHIFT_STATE_STOPPED) {
          mediaPlayer.stopTimeshiftBuffering();
        }
      }
      catch (e) {
        alert(e);
      }
      break;

    case "Blue": // return to live TV
      try {
        mediaPlayer.playFromPosition(mediaPlayer.POSITION_LIVE,
                                    mediaPlayer.PACE_PLAY);
      }
      catch (e) {
        alert(e);
      }
      break;

    case "Green":
      try {
         if (mediaPlayer.getTimeshiftInfo().state !=
                 mediaPlayer.TIMESHIFT_STATE_BUFFERING) {
           alert("Starting timeshift buffering.");
           try {
               mediaPlayer.discardTimeshiftBuffer();
           }
           catch (e) {
               alert(e);
           }
           mediaPlayer.startTimeshiftBuffering(600);
         }
      }
      catch (e) {
        alert(e);
      }
      break;

    case "Right":
      mediaPlayer.play(mediaPlayer.PACE_FASTFORWARD);
      break;
    case "Left":
      mediaPlayer.play(mediaPlayer.PACE_REWIND);
      break;
    case "Accept":
      if (mediaPlayer.getState() != mediaPlayer.STATE_PLAYING) {
          mediaPlayer.play(mediaPlayer.PACE_PLAY);
      }
      else {
          mediaPlayer.play(mediaPlayer.PACE_PAUSE);
      }
      break;
    case "Up":
      incChan();
      play(channels[currChan]);
      break;
    case "Down":
      decChan();
      play(channels[currChan]);
      break;
  }
}


function incChan() {
  currChan = currChan + 1;
  if (currChan == channels.length ) {
    currChan = 0;
  }
}

function decChan() {
    currChan = currChan - 1;
    if (currChan < 0 ) {
      currChan = channels.length - 1;
    }
}


function onUnload() {
  try {
    document.removeEventListener("keydown", onKeyDown, false);

    if ( mediaPlayer.getState != mediaPlayer.STATE_IDLE ) {
      alert("closing media player");
      mediaPlayer.close();
    }
    else {
        alert ("mediaplayer was closed");
    }

    alert("removing listeners");
    mediaPlayer.removeEventListener(mediaPlayer.ON_STATE_CHANGED,
                    onStateChanged);

    alert("removed.");
    mediaPlayer.removeEventListener(mediaPlayer.ON_POSITION_CHANGED,
                    onPositionChanged);

    alert("removed.");
    mediaPlayer.removeEventListener(mediaPlayer.ON_TIMESHIFT_STATE_CHANGED,
                    onTimeshiftStateChanged);
    alert("removed.");
    mediaPlayer.releaseInstance();
  }
  catch (e) {
    alert(e);
  }
}

