var currentOutput = 0;  // index into output device array
var e_currentOutput = 0;

var videoConfig = null;

var linespacing = 16;

var elements = null;

function onLoad() {
  document.addEventListener("keydown", onKeyDown, false);

  videoConfig = toi.videoOutputService.getVideoConfiguration();

  e_currentOutput = document.getElementById("currentOutput");
  e_currentOutput.textContent = currentOutput;

  // DOM contains an element where supported modes shall be displayed..
  e_modeSelectionList = document.getElementById("modeSelectionList");

  // ask video output device for modes, compare with TV's EDID, show list of
  // valid supported modes in green
  getModes(currentOutput);
}


function empty() {
  elements = new Array;
  while (e_modeSelectionList.childNodes.length > 0) {
    e_modeSelectionList.removeChild(e_modeSelectionList.firstChild);
  }

  displayInfo = null;
  currentlySelected = 0;
  previousColor = "#000000";
}


function getModes(output) {
  // remove existing info, if any
  empty();

  // supported modes are those returned in the EDID from the TV
 displayInfo=videoConfig.getDisplayInfo(videoConfig.getVideoOutputs()[output]);

  for (var i=0; i<displayInfo.supportedVideoModes.length; i++) {
    var t = document.createElement("text");
    t.setAttribute("x", "0");
    t.setAttribute("y", i*linespacing);
    t.textContent = res2string(displayInfo.supportedVideoModes[i]);
    e_modeSelectionList.appendChild(t);
    elements.push(t);
  }

  getAllowedModes(output);

  selectVideoMode(0);
}


function getAllowedModes(output) {
  // need a config session
  //
  var session = 0;
  try {
      session = toi.videoOutputService.createVideoConfigurationSession();
  }
  catch (e) {
      alert(e);
  }

  // the videoOutputInfo contains a list of allowed video modes for the current
  // color system (PAL_M, NTSC, etc)
  // For a list of all possible modes, use getVideoOutputCapabilityInfo()
  var Id = videoConfig.getVideoOutputs()[output];
  var modes = session.getVideoOutputInfo(Id).allowedVideoModes;

  session.releaseInstance();


  // set green color for those modes supported by both TV and video output
  for (var i=0; i<modes.length; i++) {
    for (var j=0; j<displayInfo.supportedVideoModes.length;j++) {
      if (modes[i] == displayInfo.supportedVideoModes[j]) {
        elements[j].setAttribute("fill", "#00aa00");
      }
    }
  }
}


function selectNext() {
  if (currentlySelected < elements.length - 1) {
    selectVideoMode(currentlySelected + 1);
  }
  else {
    selectVideoMode(0);
  }
}


function selectPrev() {
  if (currentlySelected > 0) {
    selectVideoMode(currentlySelected-1);
  }
  else {
    selectVideoMode(elements.length - 1);
  }
}


function selectVideoMode(mode) {
  elements[currentlySelected].setAttribute("fill", previousColor);
  currentlySelected = mode;
  previousColor = elements[currentlySelected].getAttribute("fill");
  elements[mode].setAttribute("fill", "#ff0000");
}


function accept() {
  var session = null;
  try {
    var desiredMode = displayInfo.supportedVideoModes[currentlySelected];

    // create the session
    session = toi.videoOutputService.createVideoConfigurationSession();
    session.setDefaultVideoMode(videoConfig.getVideoOutputs()[currentOutput],
                  desiredMode);
    session.apply();
    session.releaseInstance();

  }
  catch (e) {
    if (session != null) {
      session.releaseInstance();
    }
    alert(e);
  }
}


function removeOverride() {
  var session = toi.videoOutputService.createVideoConfigurationSession();
  try {
    session.resetDisplayInfo(videoConfig.getVideoOutputs()[currentOutput]);
    session.apply();
    session.releaseInstance();
  }
  catch (e) {
    session.releaseInstance();
  }

  // need to update the screen..
  empty();
  getModes(currentOutput);
}


function setOverride() {
  var session = toi.videoOutputService.createVideoConfigurationSession();
  try {
    var customModes = new Array();
    customModes = [];
    customModes.push(videoConfig.VIDEO_MODE_720P50);
    customModes.push(videoConfig.VIDEO_MODE_1080I50);

    session.setDisplayInfo(videoConfig.getVideoOutputs()[currentOutput],
                           customModes,
                           videoConfig.ASPECT_RATIO_16_9);

    session.apply();
    session.releaseInstance();

  }
  catch (e) {
    session.releaseInstance();
    alert(e);
  }


  // need to update the screen..
  empty();
  getModes(currentOutput);
}


function onKeyDown(event) {
  var key = event.keyIdentifier;
  switch (key) {
    case "U+0030":
      currentOutput = 0;
      getModes(currentOutput);
      break;
    case "U+0031":
      currentOutput = 1;
      getModes(currentOutput);
      break;
    case "U+0032":
      currentOutput = 2;
      getModes(currentOutput);
      break;
    case "Up":
      selectPrev();
      break;
    case "Down":
      selectNext();
     break;
    case "Accept":
      accept();
      break;
    case "Yellow":
      removeOverride();
      break;
    case "Red":
      setOverride();
      break;
    case "Blue":
      toi.videoOutputService.setVideoSafeMode();
      break;
  }

  e_currentOutput.textContent = currentOutput;
}



function onUnload() {
    document.removeEventListener("keydown", onKeyDown, false);
}


function res2string(res) {
  switch (res) {
  default:
  case videoConfig.NO_VIDEO_MODE:
    return "NO_VIDEO_MODE";
  case videoConfig.VIDEO_MODE_480I60:
    return "VIDEO_MODE_480I60";
  case videoConfig.VIDEO_MODE_576I50:
    return "VIDEO_MODE_576I50";
  case videoConfig.VIDEO_MODE_480P60:
    return "VIDEO_MODE_480P60";
  case videoConfig.VIDEO_MODE_576P50:
    return "VIDEO_MODE_576P50";
  case videoConfig.VIDEO_MODE_720P50:
    return "VIDEO_MODE_720P50";
  case videoConfig.VIDEO_MODE_720P60:
    return "VIDEO_MODE_720P60";
  case videoConfig.VIDEO_MODE_1080I50:
    return "VIDEO_MODE_1080I50";
  case videoConfig.VIDEO_MODE_1080I60:
    return "VIDEO_MODE_1080I60";
  case videoConfig.VIDEO_MODE_1080P23976:
    return "VIDEO_MODE_1080P23976";
  case videoConfig.VIDEO_MODE_1080P24:
    return "VIDEO_MODE_1080P24";
  case videoConfig.VIDEO_MODE_1080P25:
    return "VIDEO_MODE_1080P25";
  case videoConfig.VIDEO_MODE_1080P29970:
    return "VIDEO_MODE_1080P29970";
  case videoConfig.VIDEO_MODE_1080P30:
    return "VIDEO_MODE_1080P30";
  case videoConfig.VIDEO_MODE_1080P50:
    return "VIDEO_MODE_1080P50";
  case videoConfig.VIDEO_MODE_1080P59940:
    return "VIDEO_MODE_1080P59940";
  case videoConfig.VIDEO_MODE_1080P60:
    return "VIDEO_MODE_1080P60";
  }
}

