#!/bin/bash
#
# Creates a compressed file with information about infocast server
# 
# (c) Motorola 

OUTDIR=$1; 

if [ $UID -ne 0 ] ; then
  echo 'ERROR: This script must be run as user root.'
  exit 1
fi

echo 'Getting configuration..'

# Check Infocast installation directory
. /etc/infocast 2> /dev/null
if [ -z $INFOCAST_INSTALL ] ; then
    echo 'ERROR: Infocast server is not installed.'
    exit 1
fi

# Create file
set -- `date +%Y-%m-%d-%H_%M`
mkdir /tmp/snapshot-$1
DIRNAME=snapshot-$1

# Get the first DNS server
DNSLIST=`cat /etc/resolv.conf |grep nameserver |cut -f 2 -d' '`
DNS1=`echo $DNSLIST | cut -f 1 -d' '`

echo 'Checking network..'

case `uname` in
  Linux)
    # Network configuration
    cp /etc/sysconfig/network /tmp/$DIRNAME/

    # ifcfg-eth0
    cp /etc/sysconfig/network-scripts/ifcfg-eth* /tmp/$DIRNAME/

    # Network status
    ping -c 5 -w 5 $DNS1 > /tmp/$DIRNAME/pingdns.txt

    # chkconfig
    chkconfig --list > /tmp/$DIRNAME/chkconfig.txt

    # redhat-release
    cat /etc/redhat-release > /tmp/$DIRNAME/redhat-release.txt

    # RAM usage
    free -m > /tmp/$DIRNAME/memory.txt
    ;;

  SunOS)
    # Network configuration
    cp /etc/networks /tmp/$DIRNAME/
    cp /etc/netconfig /tmp/$DIRNAME/
    cp /etc/netmasks /tmp/$DIRNAME/

    # Network status
    ping -s $DNS1 56 5 > /tmp/$DIRNAME/pingdns.txt

    # RAM usage
    swap -s > /tmp/$DIRNAME/memory.txt
    ;;

esac

# Routing
    netstat -r > /tmp/$DIRNAME/route.txt

# NIC config
    ifconfig -a > /tmp/$DIRNAME/ifconfig

# All XML files
    cp $INFOCAST_INSTALL/*.xml /tmp/$DIRNAME/

# All DTD files
    cp $INFOCAST_INSTALL/*.dtd /tmp/$DIRNAME/

# All TXT files
    cp $INFOCAST_INSTALL/*.txt /tmp/$DIRNAME/

# bootcast file
    cp $INFOCAST_INSTALL/bootcast* /tmp/$DIRNAME/

# Infocast log file
    cp $INFOCAST_INSTALL/*.log /tmp/$DIRNAME/

# dhcpd config 
    cp /etc/dhcpd.conf /tmp/$DIRNAME/ 2>/dev/null 
    cp /var/dhcp/dhcptab /tmp/$DIRNAME/ 2>/dev/null

# Resolver
    cp /etc/resolv.conf /tmp/$DIRNAME/

# Boot log messages
    dmesg > /tmp/$DIRNAME/dmseg.txt

# Kernel version
    uname -a > /tmp/$DIRNAME/uname.txt

# Disk free
    df -k > /tmp/$DIRNAME/disk-usage.txt

# Directory structure
    ls -alR $INFOCAST_INSTALL/ > /tmp/$DIRNAME/list.txt

echo 'Compressing files..'

# Compressing files
    cd /tmp
    tar -cf $DIRNAME.tar $DIRNAME
    gzip -f -9 $DIRNAME.tar
    rm -fr $DIRNAME

    if [ -z $OUTDIR ] ; then
	echo ''
	echo 'The Script is finished.'
	echo 'Please send the file /tmp/'$DIRNAME'.tar.gz to kreatvsupport@motorola.com'
    else
	mv /tmp/$DIRNAME.tar.gz $OUTDIR
	echo $DIRNAME.tar.gz;
    fi


