#!/bin/bash


# global variables
remote_reboot_config="remotereboot_generated.xml"

MAGENTA="[01;35;40m"
YELLOW="[01;33;40m"
RESET="[00m"

debug=1

function dprint {
if [ $debug -eq 1 ]; then
  echo $@
fi
}

clear
cat <<EOF
There are two ways to determine if the STB is running the correct
software when doing a RemoteReboot:

${YELLOW}SoftwareVersion: $RESET
This way is used if you upgrade from one version to another.

For example:
You are running version 3.1 today and want to upgrade to 3.2, then you can
select to use SoftwareVersion.

${YELLOW}SoftwareDate + SoftwareTime $RESET
This way is used if you want to change bootimage within a release.

For example:
You are running 3.1 today and are very happy with that. But you have got a
new bootimage with support for MP3, also version 3.1, and you want all STBs 
to run this instead.

Do you want to create the RemoteReboot file based on SoftwareVersion
or on SoftwareDate+SofwareTime?

1. SoftwareVersion
2. SoftwareDate+SoftwareTime
EOF

echo -n "Enter how you want to reboot the STBs [1] 2: "
read howreboot

if [ "$howreboot" == "2" ]; then
    echo "You have selected to use SoftwareDate+SoftwareTime"
else
    echo "You have selected to use SoftwareVersion"
    howreboot="1"
fi

sleep 1

if [ "$howreboot" == "2" ]; then

clear
cat <<EOF
SoftwareDate

Used together with the SoftwareTime to determine whether the build
date of the current software on the IP-STB is the desired one. The
IP-STB will reboot until both values correspond to those of the
software.

Either Date + Time or Version must be specified.

This value is set automatically when building the boot image.

Type:
Numerical string

Value set:
A date on the format YYYYMMDD

$MAGENTA Note! This may make the IP-STBs reboot forever. $RESET

EOF

echo -n "Enter value for SoftwareDate: "
read softwaredate

#if [[ ! "$softwaredate" =~ "[1-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]" ]]; then
#   echo "ERROR: not in the format: YYYYMMDD"
#   exit 1
#fi

clear
cat <<EOF
SoftwareTime

Used together with the SoftwareDate to determine whether the build
date of the current software on the IP-STB is the desired one. The
IP-STB will reboot until both values correspond to those of the
software.

Either Date + Time or Version must be specified.

This value is set automatically when building the boot image.

Type:
Numerical string

Value set:
A time on the format hhmmss

$MAGENTA Note! This may make the IP-STBs reboot forever. $RESET

EOF

echo -n "Enter value for SoftwareTime: "
read softwaretime

#if [[ ! "$softwaretime" =~ "[0-9][0-9][0-9][0-9][0-9][0-9]" ]]; then
#   echo "ERROR: not in the format: hhmmss"
#   exit 1
#fi

else

clear
cat <<EOF
SoftwareVersion

Used to determine whether the version of the current software on the
IP-STB is the desired one. The IP-STB will reboot until the value
corresponds to that of the software.

This value is set automatically when building the boot image.

Type:
String

Value set:
A version

Example value:
3.0.1

$MAGENTA Note! This may make the IP-STBs reboot forever. $RESET

EOF

echo -n "Enter value for SoftwareVersion: "
read softwareversion

fi

clear
cat <<EOF
SerialIntervalStart

No IP-STBs with serial number less than SerialIntervalStart will be rebooted.

A typical serial number of a Kreatel IP-STB typically holds ten
digits, but only the first nine digits are significant. The last digit
is a control digit.

Type:
Integer

Value set:
[0 - 9999999999] 
EOF


echo -n "Enter value for SerialIntervalStart (ENTER to skip): "
read intervalstart

#skip if no SerialIntervalStart
intervalend=""
if [ ! -z "$intervalstart" ]; then

clear
cat <<EOF
SerialIntervalEnd

No IP-STBs with serial number larget than SerialIntervalEnd will be rebooted.

A typical serial number of a Kreatel IP-STB typically holds ten
digits, but only the first nine digits are significant. The last digit
is a control digit.


Type:
Integer

Value set:
[0 - 9999999999] 
EOF

echo -n "Enter value for SerialIntervalEnd: "
read intervalend

fi

clear
cat <<EOF
Severity

Determines when the IP-STB is to reboot.  

Forced Reboot = Immediately
Automatic = At standby 
Question Dialogue = Show a Notification to interact with the user. 

This requires that the Remote Reboot application is installed and started.


1. Forced Reboot
2. Automatic
3. Question Dialogue 

EOF

echo -n "Enter value for Severity, [1] 2 3: "
read severity

case "$severity" in
    "1" )
	severity="Forced Reboot"
	;;
    "2" )
	severity="Automatic"
	;;
    "3" )
	severity="Question Dialogue"
	;;
    * )
	severity="Forced Reboot"
	;;
esac

echo "Severity: $severity"

sleep 1

if [ "$severity" == "Question Dialogue" ]; then

clear
cat <<EOF
Timeout

Time to wait for user response in case of Question Dialogue before
rebooting anyway.

Type:
Numerical

Value set:
Time in seconds
(0 means wait indefinitely)

Default: 120

EOF

echo -n "Enter value for Timeout (ENTER for default): "
read timeout

if [ -z "$timeout" ]; then
    timeout="120"
fi

echo "Timeout set to: $timeout"
sleep 1


clear
cat <<EOF
Text

The informational text displayed in the user dialogue.

Type:
String

Value set:
Any string that can be displayed properly.

Default:
System maintenance reboot requested. Accept this reboot or postpone it?

EOF

echo -n "Enter notification text (ENTER for default): "
read notificationtext

if [ -z $notificationtext ]; then
    notificationtext="System maintenance reboot requested. Accept this reboot or postpone it?"
fi

echo "Text: $notificationtext"
sleep 1

clear
cat <<EOF
A possible user choice

Default: Accept

EOF

echo -n "Enter text for accept button (ENTER for default): "
read accept

if [ -z "$accept" ]; then
    accept="Accept"
fi

clear
cat <<EOF
A possible user choice

Default: Postpone

EOF

echo -n "Enter text for postpone button (ENTER for default): "
read postpone

if [ -z "$postpone" ]; then
    postpone="Postpone"
fi

fi

clear
cat <<EOF
<?xml version="1.0"?>
<!DOCTYPE RemoteRebootRequests SYSTEM "remotereboot.dtd">
<RemoteRebootRequests>
  <RemoteRebootRequest>
EOF

if [ ! -z "$softwaredate" ]; then
    echo "    <SoftwareDate>$softwaredate</SoftwareDate>"
fi

if [ ! -z "$softwaretime" ]; then
    echo "    <SoftwareTime>$softwaretime</SoftwareTime>"
fi

if [ ! -z "$softwareversion" ]; then
    echo "    <SoftwareVersion>$softwareversion</SoftwareVersion>"
fi

if [ ! -z "$intervalstart" ]; then
    echo "    <SerialIntervalStart>$intervalstart</SerialIntervalStart>"
fi

if [ ! -z "$intervalend" ]; then
    echo "    <SerialIntervalEnd>$intervalend</SerialIntervalEnd>"
fi

if [ ! -z "$severity" ]; then
    echo "    <Severity>$severity</Severity>"
fi

if [ ! -z "$timeout" ]; then
    echo "    <Timeout>$timeout</Timeout>"
fi

if [ "$severity" == "Question Dialogue" ]; then
cat <<EOF
    <Notification>
      <Text>$notificationtext</Text>
      <Button>
        <Text>$accept</Text>
        <Action>Yes</Action>
      </Button>
      <Button>
        <Text>$postpone</Text>
        <Action>No</Action>
      </Button>
    </Notification> 
EOF
fi
cat <<EOF
  </RemoteRebootRequest>
</RemoteRebootRequests>
EOF